This repository holds all XML Schema Definition (XSD) files for various IP-XACT releases. 

The original source is [Accellera](https://www.accellera.org/XMLSchema/).

# IEEE Std. 1685-20xx

**Apache License, Version 2.0**

* [IEEE Std. 1685-2022](http://www.accellera.org/XMLSchema/IPXACT/1685-2022/)  
  ✅ License: [Apache License, Version 2.0](ieee-1685-2022/LICENSE)  
  &emsp; Notices: [Notice file](ieee-1685-2022/NOTICE)


**Unknown License State**

* [IEEE Std. 1685-2014](http://www.accellera.org/XMLSchema/IPXACT/1685-2014/)  
  ⚠️ local [README](ieee-1685-2014/README.md) (text provided by Accellera) contains open source threatening rules
* [IEEE Std. 1685-2009](http://www.accellera.org/XMLSchema/SPIRIT/1685-2009/)  
  ⚠️ local [README](ieee-1685-2009/README.md) (text provided by Accellera) contains open source threatening rules
 

# SPIRIT Consortium

The Structure for Packaging, Integrating and Re-using IP within Tool-flows (SPIRIT) consortium was created to develop a
standard for more efficient integration of IP in System-on-Chip (SoC) platform design in two areas: IP meta-data
description and a tool integration API.

SPIRIT Version 1.0 was released on December 8th, 2004 and addressed SoC design at the RT level. Work had already started
to draft Version 2.0 of the standard that was to extend the specification to cover comprehensive interoperability
between tools and explicit support of Electronic System Level (ESL) Design and Verification.

Around the time of DAC 2005, the IEEE P1685 working group was formed.

**Unknown License State**

* [IP-XACT 1.5](http://www.accellera.org/XMLSchema/SPIRIT/1.5/)  
  ❌ © Copyright Accellera Systems Initiative. All rights reserved.
* [IP-XACT 1.4](http://www.accellera.org/XMLSchema/SPIRIT/1.4/)  
  ❌ © Copyright Accellera Systems Initiative. All rights reserved.
* [IP-XACT 1.2](http://www.accellera.org/XMLSchema/SPIRIT/1.2/)  
  ❌ © Copyright Accellera Systems Initiative. All rights reserved.
* [IP-XACT 1.1](http://www.accellera.org/XMLSchema/SPIRIT/1.1/)  
  ❌ © Copyright Accellera Systems Initiative. All rights reserved.
* [IP-XACT 1.0](http://www.accellera.org/XMLSchema/SPIRIT/1.0/)  
  ❌ © Copyright Accellera Systems Initiative. All rights reserved.


# Further Links:

* [Accellera](https://www.accellera.org/)


# Consumers

This repository is used by:

* 🚧 [pyEDAA.IPXACT](https://github.com/edaa-org/pyEDAA.IPXACT) as a Git submodule.


# License

Starting from 2022, the XML schemas are licensed under [Apache License 2.0](LICENSE.md). Older revisions (IEEE standards
2014 and 2009 )are licensed under a "sharing friendly" license, but prohibits modifications and derived work. The very
old revisions (released by the SPIRIT Consortium) are in unknown license state. Check each individual directory for the
license state of that revision.  
<!--
The accompanying documentation is licensed under [Creative Commons - Attribution 4.0 (CC-BY 4.0)](doc/Doc-License.rst).
-->

-------------------------

SPDX-License-Identifier: Apache-2.0
